# FastPyPI

FastPyPI is a package enabling user to create and update existing PyPI packages in an easy-to-use gui. 

(creates ```pip install XXX``` for your package)

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install FastPyPI.

```
pip install fastpypi
```

## Usage

Run a Python interpreter in console/terminal
```
>>> import fastpypi.fastpypi_core
```

This will launch a FastPyPI GUI (as in the picture).


![alt text](https://github.com/DovaX/fastpypi/blob/master/fastpypi_tool.png?raw=true)


## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## License
[MIT](https://choosealicense.com/licenses/mit/)

